@@ -5,10 +5,12 @@ class LocustNotFoundException(Exception):
 class LoadDensityTestException(Exception):
     pass
 
+
 # json
 class LoadDensityTestJsonException(LoadDensityTestException):
     pass
 
+
 class LoadDensityGenerateJsonReportException(LoadDensityTestException):
     pass
 
@@ -28,3 +30,17 @@ class LoadDensityHTMLException(LoadDensityTestException):
 class LoadDensityAddCommandException(LoadDensityTestException):
     pass
 
+
+# XML
+
+class XMLException(LoadDensityTestException):
+    pass
+
+
+class XMLTypeException(XMLException):
+    pass
+
+
+# Execute callback
+class CallbackExecutorException(LoadDensityTestException):
+    pass
