@@ -1,21 +1,36 @@
 import sys
+import time
 import types
+from inspect import getmembers, isbuiltin
 
+from je_load_density.utils.exception.exception_tags import executor_data_error, add_command_exception_tag
+from je_load_density.utils.exception.exception_tags import executor_list_error
 from je_load_density.utils.exception.exceptions import LoadDensityTestExecuteException
-from je_load_density.utils.exception.exception_tag import executor_data_error, add_command_exception_tag
-from je_load_density.utils.exception.exception_tag import executor_list_error
-from je_load_density.utils.generate_report.generate_html_report import generate_html
+from je_load_density.utils.generate_report.generate_html_report import generate_html, generate_html_report
+from je_load_density.utils.generate_report.generate_json_report import generate_json, generate_json_report
+from je_load_density.utils.generate_report.generate_xml_report import generate_xml, generate_xml_report
 from je_load_density.utils.json.json_file.json_file import read_action_json
-from je_load_density.wrapper.env_with_user.wrapper_env_and_user import loading_test_with_user
+from je_load_density.wrapper.start_wrapper.start_test import start_test
 
 
 class Executor(object):
 
     def __init__(self):
         self.event_dict = {
-            "loading_test_with_user": loading_test_with_user,
+            "user_test": start_test,
             "generate_html": generate_html,
+            "generate_html_report": generate_html_report,
+            "generate_json": generate_json,
+            "generate_json_report": generate_json_report,
+            "generate_xml": generate_xml,
+            "generate_xml_report": generate_xml_report,
+            # execute
+            "execute_action": self.execute_action,
+            "execute_files": self.execute_files,
         }
+        # get all time module builtin function and add to event dict
+        for function in getmembers(time, isbuiltin):
+            self.event_dict.update({str(function): function})
 
     def _execute_event(self, action: list):
         """
